@@ -696,6 +696,35 @@ class MariadbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DestroyDBInstance(self, request):
+        """This API is used to terminate an isolated monthly subscribed instance.
+
+        :param request: Request instance for DestroyDBInstance.
+        :type request: :class:`tencentcloud.mariadb.v20170312.models.DestroyDBInstanceRequest`
+        :rtype: :class:`tencentcloud.mariadb.v20170312.models.DestroyDBInstanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DestroyDBInstance", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DestroyDBInstanceResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DestroyHourDBInstance(self, request):
         """This API is used to terminate a pay-as-you-go instance.
 
