@@ -29,6 +29,9 @@ DBERROR = 'DBError'
 # Operation failed.
 FAILEDOPERATION = 'FailedOperation'
 
+# Failed to request a quota for resource tags.
+FAILEDOPERATION_ALLOCATEQUOTASERROR = 'FailedOperation.AllocateQuotasError'
+
 # Failed to access classic network. Please try again later. If the problem persists, please contact customer service.
 FAILEDOPERATION_BASENETWORKACCESSERROR = 'FailedOperation.BaseNetworkAccessError'
 
@@ -116,6 +119,9 @@ FAILEDOPERATION_MODIFYROGROUPERROR = 'FailedOperation.ModifyROGroupError'
 # The number of networks does not meet resource requirements.
 FAILEDOPERATION_NETWORKNUMLIMITERROR = 'FailedOperation.NetworkNumLimitError'
 
+# The operation frequency limit is exceeded. Try again later. If the problem persists, contact customer service.
+FAILEDOPERATION_OPERATEFREQUENCYLIMITEDERROR = 'FailedOperation.OperateFrequencyLimitedError'
+
 # Failed to access database management service. Please try again later. If the problem persists, please contact customer service.
 FAILEDOPERATION_OSSACCESSERROR = 'FailedOperation.OssAccessError'
 
@@ -239,6 +245,9 @@ INTERNALERROR_FLOWERROR = 'InternalError.FlowError'
 # Failed to access database management service. Please contact customer service.
 INTERNALERROR_INSTANCEDATAERROR = 'InternalError.InstanceDataError'
 
+# An exception occurred while executing the request.
+INTERNALERROR_INTERNALHTTPSERVERERROR = 'InternalError.InternalHttpServerError'
+
 # Failed to parse background data. Please contact customer service.
 INTERNALERROR_MARSHALERROR = 'InternalError.MarshalError'
 
@@ -260,9 +269,6 @@ INVALIDACCOUNTSTATUS = 'InvalidAccountStatus'
 # Incorrect instance status.
 INVALIDINSTANCESTATUS = 'InvalidInstanceStatus'
 
-# Billing error: invalid order type ID.
-INVALIDORDERNUM = 'InvalidOrderNum'
-
 # Parameter error.
 INVALIDPARAMETER = 'InvalidParameter'
 
@@ -404,12 +410,6 @@ INVALIDPARAMETERVALUE_STRUCTPARSEFAILED = 'InvalidParameterValue.StructParseFail
 # Incorrect `PID` parameter.
 INVALIDPID = 'InvalidPid'
 
-# Billing error: such operations as purchase, renewal, and configuration change are not allowed for the instance.
-INVALIDTRADEOPERATE = 'InvalidTradeOperate'
-
-# Billing error: the specified voucher is invalid.
-INVALIDVOUCHERID = 'InvalidVoucherId'
-
 # Quota limit exceeded.
 LIMITEXCEEDED = 'LimitExceeded'
 
@@ -455,6 +455,9 @@ OPERATIONDENIED_ROGROUPSTATUSERROR = 'OperationDenied.ROGroupStatusError'
 # Read-only instances do not support IPv6.
 OPERATIONDENIED_ROINSTANCEIPV6NOTSUPPORTEDERROR = 'OperationDenied.ROInstanceIpv6NotSupportedError'
 
+# This operation cannot be performed on a read-only instance in this status.
+OPERATIONDENIED_ROINSTANCESTATUSLIMITOPERROR = 'OperationDenied.ROInstanceStatusLimitOpError'
+
 # The total number of read-only nodes should not exceed the upper limit.
 OPERATIONDENIED_ROINSTANCECOUNTEXEEDERROR = 'OperationDenied.RoInstanceCountExeedError'
 
@@ -476,9 +479,6 @@ REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'
 # There are not enough resources to purchase instances of this specification in the current region.
 RESOURCEINSUFFICIENT_RESOURCENOTENOUGH = 'ResourceInsufficient.ResourceNotEnough'
 
-# Resource not found.
-RESOURCENOTFOUND = 'ResourceNotFound'
-
 # The instance does not exist.
 RESOURCENOTFOUND_INSTANCENOTFOUNDERROR = 'ResourceNotFound.InstanceNotFoundError'
 
@@ -506,5 +506,8 @@ UNKNOWNERROR = 'UnknownError'
 # Unknown parameter error.
 UNKNOWNPARAMETER = 'UnknownParameter'
 
+# The operation is not supported.
+UNSUPPORTEDOPERATION = 'UnsupportedOperation'
+
 # VPC error
 VPCERROR = 'VpcError'
