@@ -32,6 +32,9 @@ FAILEDOPERATION_CLBUNEXPECTEDERROR = 'FailedOperation.CLBUnexpectedError'
 # Not authorized to access this API
 FAILEDOPERATION_CAMNOAUTH = 'FailedOperation.CamNoAuth'
 
+# 
+FAILEDOPERATION_CLUSTERFORBIDDENTODELETE = 'FailedOperation.ClusterForbiddenToDelete'
+
 # The cluster is not found.
 FAILEDOPERATION_CLUSTERNOTFOUND = 'FailedOperation.ClusterNotFound'
 
@@ -68,18 +71,24 @@ FAILEDOPERATION_DBRECORDNOTFOUND = 'FailedOperation.DbRecordNotFound'
 # Failed to obtain security group quota.
 FAILEDOPERATION_DFWGETUSGQUOTA = 'FailedOperation.DfwGetUSGQuota'
 
+# 
+FAILEDOPERATION_ENABLEVPCCNIFAILED = 'FailedOperation.EnableVPCCNIFailed'
+
 # Failed to connect to the customer Kubernetes cluster.
 FAILEDOPERATION_KUBECLIENTCONNECTION = 'FailedOperation.KubeClientConnection'
 
 # Kubernetes API error.
 FAILEDOPERATION_KUBECOMMON = 'FailedOperation.KubeCommon'
 
-# 
+# Failed to create the Kubernetes client.
 FAILEDOPERATION_KUBERNETESCLIENTBUILDERROR = 'FailedOperation.KubernetesClientBuildError'
 
 # An error occurs while creating the cluster client.
 FAILEDOPERATION_KUBERNETESCREATEOPERATIONERROR = 'FailedOperation.KubernetesCreateOperationError'
 
+# 
+FAILEDOPERATION_KUBERNETESGETOPERATIONERROR = 'FailedOperation.KubernetesGetOperationError'
+
 # Unknown Kubernetes error.
 FAILEDOPERATION_KUBERNETESINTERNAL = 'FailedOperation.KubernetesInternal'
 
@@ -104,6 +113,9 @@ FAILEDOPERATION_QUOTAMAXNODLIMIT = 'FailedOperation.QuotaMaxNodLimit'
 # Insufficient security group quota.
 FAILEDOPERATION_QUOTAUSGLIMIT = 'FailedOperation.QuotaUSGLimit'
 
+# The sub-account does not have the required RBAC permissions.
+FAILEDOPERATION_RBACFORBIDDEN = 'FailedOperation.RBACForbidden'
+
 # A same task is in progress.
 FAILEDOPERATION_TASKALREADYRUNNING = 'FailedOperation.TaskAlreadyRunning'
 
@@ -119,6 +131,9 @@ FAILEDOPERATION_VPCCOMMON = 'FailedOperation.VpcCommon'
 # VPC record not found.
 FAILEDOPERATION_VPCRECODRNOTFOUND = 'FailedOperation.VpcRecodrNotFound'
 
+# Allowlist error.
+FAILEDOPERATION_WHITELISTUNEXPECTEDERROR = 'FailedOperation.WhitelistUnexpectedError'
+
 # Internal error.
 INTERNALERROR = 'InternalError'
 
@@ -161,6 +176,9 @@ INTERNALERROR_CLUSTERSTATE = 'InternalError.ClusterState'
 # The version of the cluster node is outdated.
 INTERNALERROR_CLUSTERUPGRADENODEVERSION = 'InternalError.ClusterUpgradeNodeVersion'
 
+# Command execution timeout.
+INTERNALERROR_CMDTIMEOUT = 'InternalError.CmdTimeout'
+
 # Internal HTTP client error
 INTERNALERROR_COMPONENTCLIENTHTTP = 'InternalError.ComponentClientHttp'
 
@@ -302,6 +320,9 @@ INTERNALERROR_VPCPEERNOTFOUND = 'InternalError.VpcPeerNotFound'
 # VPC record not found
 INTERNALERROR_VPCRECODRNOTFOUND = 'InternalError.VpcRecodrNotFound'
 
+# VstationError.
+INTERNALERROR_VSTATIONERROR = 'InternalError.VstationError'
+
 # Unknown allowlist error
 INTERNALERROR_WHITELISTUNEXPECTEDERROR = 'InternalError.WhitelistUnexpectedError'
 
@@ -326,6 +347,9 @@ INVALIDPARAMETER_CIDRCONFLICTWITHVPCCIDR = 'InvalidParameter.CidrConflictWithVpc
 # The created route conflicts with the existing global route under the VPC.
 INVALIDPARAMETER_CIDRCONFLICTWITHVPCGLOBALROUTE = 'InvalidParameter.CidrConflictWithVpcGlobalRoute'
 
+# Invalid CIDR block.
+INVALIDPARAMETER_CIDRINVALI = 'InvalidParameter.CidrInvali'
+
 # Parameter error. The CIDR block does not meet the specification.
 INVALIDPARAMETER_CIDRINVALID = 'InvalidParameter.CidrInvalid'
 
@@ -407,5 +431,8 @@ UNSUPPORTEDOPERATION = 'UnsupportedOperation'
 # Failed to enable CA because AS is disabled.
 UNSUPPORTEDOPERATION_CAENABLEFAILED = 'UnsupportedOperation.CaEnableFailed'
 
+# 
+UNSUPPORTEDOPERATION_CLUSTERNOTSUITENABLEVPCCNI = 'UnsupportedOperation.ClusterNotSuitEnableVPCCNI'
+
 # The user is not in the allowlist.
 UNSUPPORTEDOPERATION_NOTINWHITELIST = 'UnsupportedOperation.NotInWhitelist'
